LambdAWS
람다에서 자수 사용하는 AWS명령어를 래핑한 모듈입니다.
사용하려는 기능에 대한 IAM 권한만 충분히 가지고 있다면 바로 사용할수 있습니다.
만약 lambda가 아닌 로컬에서 이 모듈을 사용하려는 경우 boto3를 설치하셔야 합니다
- 현재 구현된것
- S3트리거 이벤트에 대한 S3객체 가져오기 및 다운로드 작업
- s3 -> sns -> 람다 트리거 이벤트에 대한 S3객체 가져오기 및 다운로드 작업

계획
- SNS트리거 이벤트에 대한 정보 추출
- SNS로 메시지 전송
